@@ -268,7 +268,7 @@ get_relative_path (GFile *parent, GFile *file)
 	{
 		if (g_file_equal (parent, file))
 		{
-			relative = g_strdup ("");
+			relative = g_strdup (".");
 		}
 		else
 		{
@@ -611,6 +611,7 @@ amp_project_update_root (AmpProject *project, AmpProject *new_project)
 	project->configure_file = new_project->configure_file;
 	new_project->configure_file = NULL;
 	project->configure_token = new_project->configure_token;
+	new_project->configure_token = NULL;
 
 	hash = project->groups;
 	project->groups = new_project->groups;
@@ -729,7 +730,7 @@ amp_project_load_properties (AmpProject *project, AnjutaToken *macro, AnjutaToke
 
 				arg = anjuta_token_nth_word (args, info->position);
 				g_free (new_prop->value);
-				new_prop->value = anjuta_token_evaluate (arg);
+				new_prop->value = anjuta_token_evaluate_name (arg);
 			}
 			else
 			{
@@ -743,7 +744,7 @@ amp_project_load_properties (AmpProject *project, AnjutaToken *macro, AnjutaToke
 					AnjutaToken *arg;
 
 					arg = anjuta_token_nth_word (args, 0);
-					new_prop->value = anjuta_token_evaluate (arg);
+					new_prop->value = anjuta_token_evaluate_name (arg);
 					if (new_prop->value == NULL) new_prop->value = g_strdup(" ");
 				}
 			}
@@ -1260,7 +1261,7 @@ project_load_target_properties (AmpProject *project, AnjutaProjectNode *parent,
 		/* Create property */
 		list = anjuta_token_last_item (variable);
 		type = anjuta_token_get_type (variable);
-		value = anjuta_token_evaluate (list);
+		value = anjuta_token_evaluate_name (list);
 		prop = amp_property_new (NULL, type, 0, value, list);
 
 		if (parent == NULL)
@@ -1307,7 +1308,7 @@ project_load_group_properties (AmpProject *project, AnjutaProjectNode *parent, A
 	/* Create property */
 	list = anjuta_token_last_item (variable);
 	name = anjuta_token_evaluate (anjuta_token_first_word (variable));
-	value = anjuta_token_evaluate (list);
+	value = anjuta_token_evaluate_name (list);
 
 	prop = amp_property_new (name, anjuta_token_get_type (variable), 0, value, list);
 
@@ -1365,7 +1366,7 @@ project_load_subdirs (AmpProject *project, AnjutaToken *list, AnjutaProjectNode
 			else
 			{
 				/* Create new group */
-				group = amp_group_node_new (subdir, dist_only);
+				group = amp_group_node_new (subdir, value, dist_only);
 
 				/* Group can be NULL if the name is not valid */
 				if (group != NULL)
@@ -1667,6 +1668,7 @@ amp_project_load_root (AmpProject *project, GError **error)
 	GFile *root_file;
 	GFile *configure_file;
 	AnjutaTokenFile *configure_token_file;
+	AnjutaProjectNode *source;
 	GError *err = NULL;
 
 	root_file = anjuta_project_node_get_file (ANJUTA_PROJECT_NODE (project));
@@ -1701,6 +1703,8 @@ amp_project_load_root (AmpProject *project, GError **error)
 	/* Parse configure */
 	configure_token_file = amp_project_set_configure (project, configure_file);
 	amp_project_add_file (project, configure_file, configure_token_file);
+	source = amp_source_node_new (configure_file, ANJUTA_PROJECT_PROJECT | ANJUTA_PROJECT_FRAME | ANJUTA_PROJECT_READ_ONLY);
+	anjuta_project_node_append (ANJUTA_PROJECT_NODE (project), source);
 	arg = anjuta_token_file_load (configure_token_file, NULL);
 	g_hash_table_remove_all (project->ac_variables);
 	scanner = amp_ac_scanner_new (project);
@@ -2194,7 +2198,9 @@ static PmCommandWork amp_save_job = {amp_save_setup, amp_save_work, amp_save_com
 static gboolean
 amp_add_before_setup (PmJob *job)
 {
-	anjuta_project_node_insert_before (job->parent, job->sibling, job->node);
+	/* If add is called to add the root group, the node is already existing */
+	if (job->parent != job->node)
+		anjuta_project_node_insert_before (job->parent, job->sibling, job->node);
 
 	return TRUE;
 }
@@ -2202,7 +2208,9 @@ amp_add_before_setup (PmJob *job)
 static gboolean
 amp_add_after_setup (PmJob *job)
 {
-	anjuta_project_node_insert_after (job->parent, job->sibling, job->node);
+	/* If add is called to add the root group, the node is already existing */
+	if (job->parent != job->node)
+		anjuta_project_node_insert_after (job->parent, job->sibling, job->node);
 
 	return TRUE;
 }
