@@ -34,12 +34,11 @@
 #include "cpp-java-indentation.h"
 #include "cpp-java-utils.h"
 
-#define PREF_INDENT_STATEMENT_SIZE "cpp-indent-statement-size"
-#define PREF_INDENT_BRACE_SIZE "cpp-indent-brace-size"
-#define PREF_INDENT_PARANTHESE_LINEUP "cpp-indent-paranthese-lineup"
-#define PREF_INDENT_PARANTHESE_SIZE "cpp-indent-paranthese-size"
-#define PREF_BRACE_AUTOCOMPLETION "cpp-brace-autocompletion"
-#define PREF_COMMENT_LEADING_ASTERISK "cpp-multiline-leading-asterisk"
+#define PREF_INDENT_BRACE_SIZE "indent-brace-size"
+#define PREF_INDENT_PARANTHESE_LINEUP "indent-paranthese-lineup"
+#define PREF_INDENT_PARANTHESE_SIZE "indent-paranthese-size"
+#define PREF_BRACE_AUTOCOMPLETION "brace-autocompletion"
+#define PREF_COMMENT_LEADING_ASTERISK "multiline-leading-asterisk"
 
 #define TAB_SIZE (ianjuta_editor_get_tabsize (editor, NULL))
 #define USE_SPACES_FOR_INDENTATION (ianjuta_editor_get_use_spaces (editor, NULL))
@@ -47,7 +46,7 @@
 #define INDENT_SIZE \
 	(plugin->param_statement_indentation >= 0? \
 		plugin->param_statement_indentation : \
-		g_settings_get_int (plugin->settings, PREF_INDENT_STATEMENT_SIZE))
+		g_settings_get_int (plugin->editor_settings, IANJUTA_EDITOR_INDENT_WIDTH_KEY))
 
 #define BRACE_INDENT \
 	(plugin->param_brace_indentation >= 0? \
@@ -120,10 +119,39 @@ get_line_indentation (IAnjutaEditor *editor, gint line_num)
 {
 	IAnjutaIterable *line_begin, *line_end;
 	gchar *line_string, *idx;
-	gint line_indent = 0;
+	gint line_indent = 0, left_braces = 0, right_braces = 0;
+	gchar ch;
 
+	line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
+
+	/* Find the line which contains the left brace matching last right brace on current line */
+
+	do
+	{
+		while (ianjuta_iterable_previous (line_end, NULL))
+		{
+			ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (line_end), 0, NULL);
+			if (ch == ')')
+				right_braces++;
+			if (ch == '(')
+				left_braces++;
+			if (iter_is_newline (line_end, ch))
+			{
+				break;
+			}
+		}
+		if (right_braces != left_braces)
+		{
+			line_num --;
+			g_object_unref (line_end);
+			line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
+		}
+	} while (right_braces != left_braces && line_num >= 0);
+
+	g_object_unref (line_end);
 	line_begin = ianjuta_editor_get_line_begin_position (editor, line_num, NULL);
 	line_end = ianjuta_editor_get_line_end_position (editor, line_num, NULL);
+
 	/*
 	DEBUG_PRINT ("%s: line begin = %d, line end = %d", __FUNCTION__,
 				 line_begin, line_end);
