@@ -64,18 +64,22 @@ static const gchar *valid_makefiles[] = {"GNUmakefile", "makefile", "Makefile",
 static MkpNodeInfo MkpNodeInformation[] = {
 	{{ANJUTA_PROJECT_GROUP,
 	N_("Group"),
-	""}},
+	"",
+	NULL}},
 
 	{{ANJUTA_PROJECT_SOURCE,
 	N_("Source"),
-	""}},
+	"",
+	NULL}},
 
 	{{ANJUTA_PROJECT_TARGET,
 	N_("Unknown"),
-	"text/plain"}},
+	"text/plain",
+	NULL}},
 
 	{{ANJUTA_PROJECT_UNKNOWN,
 	NULL,
+	NULL,
 	NULL}}
 };
 
@@ -497,6 +501,7 @@ project_load_makefile (MkpProject *project, GFile *file, MkpGroup *parent, GErro
 		{
 			g_set_error (error, IANJUTA_PROJECT_ERROR,
 						IANJUTA_PROJECT_ERROR_PROJECT_MALFORMED,
+						"%s",
 						_("Unable to parse make file"));
 		}
 
